=====
gravy
=====

Overview
--------

Calculate the GRAVY score of a amino acid sequence.

Installation
------------

To install gravy, you can use `pip`. Open your terminal and run:

.. code-block:: bash

    pip install gravy

License
-------

This project is licensed under the MIT License.

Links
-----

* `Download <https://pypi.org/project/gravy/#files>`_
* `Source <https://github.com/johannes-programming/gravy>`_ 

Credits
-------
- Author: Johannes Programming
- Email: johannes-programming@posteo.org

Thank you for using gravy!
